==> james-project-3.4.0-source-release.zip: james-project-3.4.0/backends-common/elasticsearch/src/test/java/org/apache/james/backends/es/DockerElasticSearchRule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.backends.es;

import org.junit.rules.ExternalResource;

public class DockerElasticSearchRule extends ExternalResource {

    private final DockerElasticSearch dockerElasticSearch = DockerElasticSearchSingleton.INSTANCE;

    @Override
    protected void before() throws Throwable {
        dockerElasticSearch.start();
    }

    @Override
    protected void after() {
        dockerElasticSearch.cleanUpData();
    }

    public ClientProvider clientProvider() {
        return dockerElasticSearch.clientProvider();
    }

    public void awaitForElasticSearch() {
        dockerElasticSearch.flushIndices();
    }

    public DockerElasticSearch getDockerElasticSearch() {
        return dockerElasticSearch;
    }
}

==> james-project-3.5.0-source-release.zip: james-project-3.5.0/backends-common/elasticsearch/src/test/java/org/apache/james/backends/es/DockerElasticSearchRule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.backends.es;

import org.junit.rules.ExternalResource;

public class DockerElasticSearchRule extends ExternalResource {

    private final DockerElasticSearch dockerElasticSearch = DockerElasticSearchSingleton.INSTANCE;

    @Override
    protected void before() {
        dockerElasticSearch.start();
    }

    @Override
    protected void after() {
        dockerElasticSearch.cleanUpData();
    }

    public ClientProvider clientProvider() {
        return dockerElasticSearch.clientProvider();
    }

    public void awaitForElasticSearch() {
        dockerElasticSearch.flushIndices();
    }

    public DockerElasticSearch getDockerElasticSearch() {
        return dockerElasticSearch;
    }
}
